==> 3.0.57.tar.gz: android/src/main/kotlin/com/spectus/iap/spectus_in_app_purchase/SpectusInAppPurchasePlugin.kt <==
package com.spectus.iap.spectus_in_app_purchase

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.Handler
import android.util.Log
import androidx.annotation.NonNull
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry
import io.flutter.plugin.common.PluginRegistry.Registrar

/** SpectusInAppPurchasePlugin */
class SpectusInAppPurchasePlugin: FlutterPlugin, MethodCallHandler, ActivityAware, PluginRegistry.ActivityResultListener{

 // private lateinit var channel : MethodChannel
  var helper : IAPHelper? = null
  var productID : String? = ""
  var isSubscription : Boolean = false
  var productIDs : List<String> = listOf()
  var mContext1 : Context? = null
  var mActivity : Activity? = null
  var mContext : Context? = null
  var operationResult : Result? = null

    override fun onDetachedFromActivity() {
        //
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        onAttachedToActivity(binding)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        Log.e("onAttachedToActivity","Called")
        if(binding.activity == null){
            Log.e("binding.activity","null")
        }
        mActivity = binding.activity
        binding.addActivityResultListener(this)
    }

    override fun onDetachedFromActivityForConfigChanges() {
        TODO("Not yet implemented")
    }

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    val channel = MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "spectus_in_app_purchase")
    mContext = flutterPluginBinding.applicationContext
    //mContext = mContext1 as Activity
    channel.setMethodCallHandler(this)
  }

  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "spectus_in_app_purchase")
      channel.setMethodCallHandler(SpectusInAppPurchasePlugin())
      //helper = IAPHelper()
    }
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {

      android.util.Log.e("onMethodCall"," "+call.method)

    if (call.method == "getPlatformVersion") {
      result.success("Android ${android.os.Build.VERSION.RELEASE}")
    }
    else if (call.method == "getSKUProductListWith") {
        productIDs = call.argument<List<String>>("productIDs")!!
        isSubscription = call.argument<Boolean>("isSubscription")!!
//        productID = call.argument<String>("productID")!!
        // context = call.argument<Context>("context")
        operationResult = result
        android.util.Log.e("Productid"," "+productID)
        android.util.Log.e("helper"," "+helper)

        if(mActivity==null){
            Log.e("Mactivity","Null")
        }

        IAPHelper().getSKUProductListWith(mActivity!!,
            mContext!!,
            productIDs!!,
            isSubscription,
            { error, prodcutDetails ->
                Log.e("Callback in Dart","")
                if (error != null) {
                    var array : ArrayList<Map<String, String>> = arrayListOf()
                    Log.e("Inside Error Log","")
                    mActivity!!.runOnUiThread(Runnable {
                        //call the methodChannel.invokeMethod here to avoid @UiThread exception
                        result.error("1", "Array Empty", "NoDetails")
                    })
                } else {
                    if (operationResult != null) {
                        Log.e("Operation Not Null","" + operationResult!!.toString())
                        mActivity!!.runOnUiThread(Runnable {
                            //call the methodChannel.invokeMethod here to avoid @UiThread exception
                            result.success(prodcutDetails)
                        })

                      /*  val mainHandler = Handler(mContext!!.mainLooper)

                        val myRunnable = // This is your code
                                Runnable {
                                    result.success(prodcutDetails)
                                }
                        mainHandler.post(myRunnable)*/
//                            operationResult!!.success(prodcutDetails!!)
                    } else {
                        Log.e("Operation is Null","")
                        operationResult!!.error("2","No products found!", "NA")
                    }
                }
            })
    }
    else if (call.method == "startInAppPurchaseWith") {
      productID = call.argument<String>("productID")
        isSubscription = call.argument<Boolean>("isSubscription")!!
     // context = call.argument<Context>("context")
      operationResult = result
     android.util.Log.e("Productid"," "+productID)
     android.util.Log.e("helper"," "+helper)

        if(mActivity==null){
            Log.e("Mactivity","Null")
        }

        IAPHelper().startInAppPurchaseWith(mActivity!!,
                mContext!!,
                productID!!,
                isSubscription,
                { error, purchaseObject, transactionID ->
                    if (error != null) {
                        mActivity!!.runOnUiThread(Runnable {
                            //call the methodChannel.invokeMethod here to avoid @UiThread exception
                            Log.e("Failuter => ","Cancelled => " + error!!)
                            if (error!! != "") {
                                Log.e("Inside Error Not Empty => ","")
                                result.success("")
                            } else {
                                Log.e("Inside Error Empty => ","")
                                result.success("NA")
                            }
                        })
                    }
                    else if (transactionID != null) {
                        Log.e("PRODUCT ID ==>> ","" + transactionID)
                        mActivity!!.runOnUiThread(Runnable {
                            //call the methodChannel.invokeMethod here to avoid @UiThread exception
                            Log.e("Success Purchase => ","Purchased")
                            result.success(transactionID)
                        })


                        /*  val mainHandler = Handler(mContext!!.mainLooper)

                          val myRunnable = // This is your code
                                  Runnable {
                                      Log.e("Success Purchase => ","Purchased")
                                  }
                          mainHandler.post(myRunnable)*/
//            operationResult!!.success(transactionID)
                    }
      })
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
  //  channel.setMethodCallHandler(null)
  }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {
        //TODO("Not yet implemented")
        return  false
    }

    /*override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        //TODO("Not yet implemented")
    }*/
}

==> 4.0.1.tar.gz: android/src/main/kotlin/com/spectus/iap/spectus_in_app_purchase/SpectusInAppPurchasePlugin.kt <==
package com.spectus.iap.spectus_in_app_purchase

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.Handler
import android.util.Log
import androidx.annotation.NonNull
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry
import io.flutter.plugin.common.PluginRegistry.Registrar

/** SpectusInAppPurchasePlugin */
class SpectusInAppPurchasePlugin: FlutterPlugin, MethodCallHandler, ActivityAware, PluginRegistry.ActivityResultListener{

 // private lateinit var channel : MethodChannel
  var helper : IAPHelper? = null
  var productID : String? = ""
  var isSubscription : Boolean = false
  var productIDs : List<String> = listOf()
  var mContext1 : Context? = null
  var mActivity : Activity? = null
  var mContext : Context? = null
  var operationResult : Result? = null

    override fun onDetachedFromActivity() {
        //
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        onAttachedToActivity(binding)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        Log.e("onAttachedToActivity","Called")
        if(binding.activity == null){
            Log.e("binding.activity","null")
        }
        mActivity = binding.activity
        binding.addActivityResultListener(this)
    }

    override fun onDetachedFromActivityForConfigChanges() {
        TODO("Not yet implemented")
    }

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    val channel = MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "spectus_in_app_purchase")
    mContext = flutterPluginBinding.applicationContext
    //mContext = mContext1 as Activity
    channel.setMethodCallHandler(this)
  }

  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "spectus_in_app_purchase")
      channel.setMethodCallHandler(SpectusInAppPurchasePlugin())
      //helper = IAPHelper()
    }
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {

      android.util.Log.e("onMethodCall"," "+call.method)

    if (call.method == "getPlatformVersion") {
      result.success("Android ${android.os.Build.VERSION.RELEASE}")
    }
    else if (call.method == "getSKUProductListWith") {
        productIDs = call.argument<List<String>>("productIDs")!!
        isSubscription = call.argument<Boolean>("isSubscription")!!
//        productID = call.argument<String>("productID")!!
        // context = call.argument<Context>("context")
        operationResult = result
        android.util.Log.e("Productid"," "+productID)
        android.util.Log.e("helper"," "+helper)

        if(mActivity==null){
            Log.e("Mactivity","Null")
        }

        IAPHelper().getSKUProductListWith(mActivity!!,
            mContext!!,
            productIDs!!,
            isSubscription,
            { error, prodcutDetails ->
                Log.e("Callback in Dart","")
                if (error != null) {
                    var array : ArrayList<Map<String, String>> = arrayListOf()
                    Log.e("Inside Error Log","")
                    mActivity!!.runOnUiThread(Runnable {
                        //call the methodChannel.invokeMethod here to avoid @UiThread exception
                        result.error("1", "Array Empty", "NoDetails")
                    })
                } else {
                    if (operationResult != null) {
                        Log.e("Operation Not Null","" + operationResult!!.toString())
                        mActivity!!.runOnUiThread(Runnable {
                            //call the methodChannel.invokeMethod here to avoid @UiThread exception
                            result.success(prodcutDetails)
                        })

                      /*  val mainHandler = Handler(mContext!!.mainLooper)

                        val myRunnable = // This is your code
                                Runnable {
                                    result.success(prodcutDetails)
                                }
                        mainHandler.post(myRunnable)*/
//                            operationResult!!.success(prodcutDetails!!)
                    } else {
                        Log.e("Operation is Null","")
                        operationResult!!.error("2","No products found!", "NA")
                    }
                }
            })
    }
    else if (call.method == "startInAppPurchaseWith") {
      productID = call.argument<String>("productID")
        isSubscription = call.argument<Boolean>("isSubscription")!!
     // context = call.argument<Context>("context")
      operationResult = result
     android.util.Log.e("Productid"," "+productID)
     android.util.Log.e("helper"," "+helper)

        if(mActivity==null){
            Log.e("Mactivity","Null")
        }

        IAPHelper().startInAppPurchaseWith(mActivity!!,
                mContext!!,
                productID!!,
                isSubscription,
                { error, purchaseObject, transactionID ->
                    if (error != null) {
                        mActivity!!.runOnUiThread(Runnable {
                            //call the methodChannel.invokeMethod here to avoid @UiThread exception
                            Log.e("Failuter => ","Cancelled => " + error!!)
                            if (error!! != "") {
                                Log.e("Inside Error Not Empty => ","")
                                result.success(error)
                            } else {
                                Log.e("Inside Error Empty => ","")
                                result.success("NA")
                            }
                        })
                    }
                    if (transactionID != null) {
                        Log.e("PRODUCT ID ==>> ","" + transactionID)
                        mActivity!!.runOnUiThread(Runnable {
                            //call the methodChannel.invokeMethod here to avoid @UiThread exception
                            Log.e("Success Purchase => ","Purchased")
                            result.success(transactionID)
                        })


                        /*  val mainHandler = Handler(mContext!!.mainLooper)

                          val myRunnable = // This is your code
                                  Runnable {
                                      Log.e("Success Purchase => ","Purchased")
                                  }
                          mainHandler.post(myRunnable)*/
//            operationResult!!.success(transactionID)
                    }
      })
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
  //  channel.setMethodCallHandler(null)
  }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {
        //TODO("Not yet implemented")
        return  false
    }

    /*override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        //TODO("Not yet implemented")
    }*/
}
